@@ -1,38 +1,13 @@
-# Test::DistManifest
-#  Tests that your manifest matches the distribution as it exists.
-#
-# $Id: DistManifest.pm 10671 2009-12-29 01:49:23Z FREQUENCY@cpan.org $
-
 package Test::DistManifest;
+BEGIN {
+  $Test::DistManifest::VERSION = '1.011';
+}
+# ABSTRACT: Author test that validates a package MANIFEST
 
 use strict;
 use warnings;
 use Carp ();
 
-=head1 NAME
-
-Test::DistManifest - Author test that validates a package MANIFEST
-
-=head1 VERSION
-
-Version 1.009 ($Id: DistManifest.pm 10671 2009-12-29 01:49:23Z FREQUENCY@cpan.org $)
-
-=cut
-
-our $VERSION = '1.009';
-$VERSION = eval $VERSION;
-
-=head1 EXPORTS
-
-By default, this module exports the following functions:
-
-=over
-
-=item * manifest_ok
-
-=back
-
-=cut
 
 # File management commands
 use Cwd ();
@@ -79,111 +54,6 @@ sub import {
   return;
 }
 
-=head1 DESCRIPTION
-
-This module provides a simple method of testing that a MANIFEST matches the
-distribution.
-
-It tests three things:
-
-=over
-
-=item 1
-
-Everything in B<MANIFEST> exists
-
-=item 2
-
-Everything in the package is listed in B<MANIFEST>, or subsequently matches
-a regular expression mask in B<MANIFEST.SKIP>
-
-=item 3
-
-Nothing exists in B<MANIFEST> that also matches a mask in B<MANIFEST.SKIP>,
-so as to avoid an unsatisfiable dependency conditions
-
-=back
-
-If there is no B<MANIFEST.SKIP> included in your distribution, this module
-will replicate the toolchain behaviour of using the default system-wide
-MANIFEST.SKIP file. To view the contents of this file, use the command:
-
-  $ perldoc -m ExtUtils::MANIFEST.SKIP
-
-=head1 SYNOPSIS
-
-  use Test::More;
-
-  # This is the common idiom for author test modules like this, but see
-  # the full example in examples/checkmanifest.t and, more importantly,
-  # Adam Kennedy's article: http://use.perl.org/~Alias/journal/38822
-  eval 'use Test::DistManifest';
-  if ($@) {
-    plan skip_all => 'Test::DistManifest required to test MANIFEST';
-  }
-
-  manifest_ok('MANIFEST', 'MANIFEST.SKIP'); # Default options
-
-  manifest_ok(); # Functionally equivalent to above
-
-=head1 COMPATIBILITY
-
-This module was tested under Perl 5.10.0, using Debian Linux. However, because
-it's Pure Perl and doesn't do anything too obscure, it should be compatible
-with any version of Perl that supports its prerequisite modules.
-
-If you encounter any problems on a different version or architecture, please
-contact the maintainer.
-
-=head1 FUNCTIONS
-
-=head2 manifest_ok
-
-  manifest_ok( $manifest, $skipfile )
-
-This subroutine checks the manifest list contained in C<$manifest> by using
-C<Module::Manifest> to determine the list of files and then checking for the
-existence of all such files. Then, it checks if there are any files in the
-distribution that were not specified in the C<$manifest> file but do not match
-any regular expressions provided in the C<$skipfile> exclusion file.
-
-If your MANIFEST file is generated by a module installation toolchain system
-such as L<ExtUtils::MakeMaker>, L<Module::Build> or L<Module::Install>, then
-you shouldn't have any problems with these files. It's just a helpful test
-to remind you to update these files, using:
-
-  $ make manifest # For ExtUtils::MakeMaker
-  $ ./Build manifest # For Module::Build
-
-=head2 Non-Fatal Errors
-
-By default, errors in the B<MANIFEST> or B<MANIFEST.SKIP> files are treated
-as fatal, which really is the purpose of using C<Test::DistManifest> as part
-of your author test suite.
-
-In some cases this is not desirable behaviour, such as with the Debian Perl
-Group, which runs all tests - including author tests - as part of its module
-packaging process. This wreaks havoc because Debian adds its control files
-in C<debian/> downstream, and that directory or its files are generally not
-in B<MANIFEST.SKIP>.
-
-By setting the environment variable B<MANIFEST_WARN_ONLY> to a true value,
-errors will be non-fatal - they show up as diagnostic messages only, but all
-tests pass from the perspective of C<Test::Harness>.
-
-This can be used in a test script as:
-
-  $ENV{MANIFEST_WARN_ONLY} = 1;
-
-or from other shell scripts as:
-
-  export MANIFEST_WARN_ONLY=1
-
-Note that parsing errors in B<MANIFEST> and circular dependencies will
-always be considered fatal. The author is not aware of any cases where
-other behaviour would be useful.
-
-=cut
 
 sub manifest_ok {
   my $warn_only = $ENV{MANIFEST_WARN_ONLY} || 0;
@@ -350,6 +220,125 @@ sub manifest_ok {
   return;
 }
 
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Test::DistManifest - Author test that validates a package MANIFEST
+
+=head1 VERSION
+
+version 1.011
+
+=head1 SYNOPSIS
+
+  use Test::More;
+
+  # This is the common idiom for author test modules like this, but see
+  # the full example in examples/checkmanifest.t and, more importantly,
+  # Adam Kennedy's article: http://use.perl.org/~Alias/journal/38822
+  eval 'use Test::DistManifest';
+  if ($@) {
+    plan skip_all => 'Test::DistManifest required to test MANIFEST';
+  }
+
+  manifest_ok('MANIFEST', 'MANIFEST.SKIP'); # Default options
+
+  manifest_ok(); # Functionally equivalent to above
+
+=head1 DESCRIPTION
+
+This module provides a simple method of testing that a MANIFEST matches the
+distribution.
+
+It tests three things:
+
+=over
+
+=item 1
+
+Everything in B<MANIFEST> exists
+
+=item 2
+
+Everything in the package is listed in B<MANIFEST>, or subsequently matches
+a regular expression mask in B<MANIFEST.SKIP>
+
+=item 3
+
+Nothing exists in B<MANIFEST> that also matches a mask in B<MANIFEST.SKIP>,
+so as to avoid an unsatisfiable dependency conditions
+
+=back
+
+If there is no B<MANIFEST.SKIP> included in your distribution, this module
+will replicate the toolchain behaviour of using the default system-wide
+MANIFEST.SKIP file. To view the contents of this file, use the command:
+
+  $ perldoc -m ExtUtils::MANIFEST.SKIP
+
+=head1 EXPORTS
+
+By default, this module exports the following functions:
+
+=over
+
+=item * manifest_ok
+
+=back
+
+=head1 FUNCTIONS
+
+=head2 manifest_ok
+
+  manifest_ok( $manifest, $skipfile )
+
+This subroutine checks the manifest list contained in C<$manifest> by using
+C<Module::Manifest> to determine the list of files and then checking for the
+existence of all such files. Then, it checks if there are any files in the
+distribution that were not specified in the C<$manifest> file but do not match
+any regular expressions provided in the C<$skipfile> exclusion file.
+
+If your MANIFEST file is generated by a module installation toolchain system
+such as L<ExtUtils::MakeMaker>, L<Module::Build> or L<Module::Install>, then
+you shouldn't have any problems with these files. It's just a helpful test
+to remind you to update these files, using:
+
+  $ make manifest # For ExtUtils::MakeMaker
+  $ ./Build manifest # For Module::Build
+
+=head2 Non-Fatal Errors
+
+By default, errors in the B<MANIFEST> or B<MANIFEST.SKIP> files are treated
+as fatal, which really is the purpose of using C<Test::DistManifest> as part
+of your author test suite.
+
+In some cases this is not desirable behaviour, such as with the Debian Perl
+Group, which runs all tests - including author tests - as part of its module
+packaging process. This wreaks havoc because Debian adds its control files
+in C<debian/> downstream, and that directory or its files are generally not
+in B<MANIFEST.SKIP>.
+
+By setting the environment variable B<MANIFEST_WARN_ONLY> to a true value,
+errors will be non-fatal - they show up as diagnostic messages only, but all
+tests pass from the perspective of C<Test::Harness>.
+
+This can be used in a test script as:
+
+  $ENV{MANIFEST_WARN_ONLY} = 1;
+
+or from other shell scripts as:
+
+  export MANIFEST_WARN_ONLY=1
+
+Note that parsing errors in B<MANIFEST> and circular dependencies will
+always be considered fatal. The author is not aware of any cases where
+other behaviour would be useful.
+
 =head1 GUTS
 
 This module internally plans 4 tests:
@@ -403,14 +392,6 @@ Example code:
   manifest_ok(); # 4 tests
   ok(1, 'is 1 true?');
 
-=head1 AUTHOR
-
-Jonathan Yu E<lt>jawnsy@cpan.orgE<gt>
-
-=head2 CONTRIBUTORS
-
-Your name here ;-)
-
 =head1 ACKNOWLEDGEMENTS
 
 =over
@@ -428,71 +409,12 @@ MANIFEST but explictly skipped by MANIFEST.SKIP.
 
 =back
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Test::DistManifest
-
-You can also look for information at:
-
-=over
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-Dist-Manifest>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Test-Dist-Manifest>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Test-Dist-Manifest>
-
-=item * CPAN Request Tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Dist-Manifest>
-
-=item * CPAN Testing Service (Kwalitee Tests)
-
-L<http://cpants.perl.org/dist/overview/Test-DistManifest>
-
-=back
-
-=head1 REPOSITORY
-
-You can access the most recent development version of this module at:
-
-L<http://svn.ali.as/cpan/trunk/Test-DistManifest>
-
-If you are a CPAN developer and would like to make modifications to the
-code base, please contact Adam Kennedy E<lt>adamk@cpan.orgE<gt>, the
-repository administrator. I only ask that you contact me first to discuss
-the changes you wish to make to the distribution.
-
-=head1 FEEDBACK
-
-Please send relevant comments, rotten tomatoes and suggestions directly to
-the maintainer noted above.
-
-If you have a bug report or feature request, please file them on the CPAN
-Request Tracker at L<http://rt.cpan.org>. If you are able to submit your
-bug report in the form of failing unit tests, you are B<strongly> encouraged
-to do so.
-
 =head1 SEE ALSO
 
 L<Test::CheckManifest>, a module providing similar functionality
 
 =head1 CAVEATS
 
-=head2 KNOWN BUGS
-
-There are no known bugs as of this release.
-
-=head2 LIMITATIONS
-
 =over
 
 =item *
@@ -512,38 +434,25 @@ the module; the emphasis should be on generating helpful error messages.
 
 =back
 
-=head1 QUALITY ASSURANCE METRICS
+=head1 BUGS
 
-=head2 TEST COVERAGE
-  
-  File                     stmt   bran   cond   sub    pod   total
-  ----------------------- ------ ------ ------ ------ ------ ------
-  Test/DistManifest.pm    96.1   95.8   100.0  100.0  100.0  96.8
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-DistManifest
 
-=head1 LICENSE
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-Copyright 2008-2009 by Jonathan Yu <jawnsy@cpan.org>
+=head1 AUTHOR
 
-This package is distributed under the same terms as Perl itself. Please
-see the F<LICENSE> file included in this distribution for full details of
-these terms.
+Jonathan Yu <jawnsy@cpan.org>
 
-=head1 DISCLAIMER OF WARRANTY
+=head1 COPYRIGHT AND LICENSE
 
-This software is provided by the copyright holders and contributors 
-"AS IS" and ANY EXPRESS OR IMPLIED WARRANTIES, including, but not 
-limited to, the IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
-A PARTICULAR PURPOSE ARE DISCLAIMED. 
+This software is copyright (c) 2011 by Jonathan Yu <jawnsy@cpan.org>.
 
-In no event shall the copyright owner or contributors be liable for 
-any direct, indirect, incidental, special, exemplary or consequential 
-damages (including, but not limited to, procurement of substitute 
-goods or services; loss of use, data or profits; or business 
-interruption) however caused and on any theory of liability, whether 
-in contract, strict liability or tort (including negligence or 
-otherwise) arising in any way out of the use of this software, even if 
-advised of the possibility of such damage. 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
